==> rc-ui-lib-2.1.1.tgz: package/es/flex/FlexItem.js <==
var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
import React, { useContext } from "react";
import classnames from "classnames";
import FlexContext from "./FlexContext";
import ConfigProviderContext from "../config-provider/ConfigProviderContext";
const FlexItem = (props) => {
  const {
    prefixCls,
    createNamespace
  } = useContext(ConfigProviderContext);
  const [bem] = createNamespace("flexitem", prefixCls);
  const _a = props, {
    style,
    className,
    span,
    children,
    flex
  } = _a, others = __objRest(_a, [
    "style",
    "className",
    "span",
    "children",
    "flex"
  ]);
  const classes = classnames(bem([span == null ? void 0 : span.toString()]), className);
  const parseFlex = (_flex) => {
    if (typeof _flex === "number") {
      return `${_flex} ${_flex} auto`;
    }
    if (/^\d+(\.\d+)?(px|em|rem|%)$/.test(_flex)) {
      return `0 0 ${_flex}`;
    }
    return _flex;
  };
  return /* @__PURE__ */ React.createElement(FlexContext.Consumer, null, ({
    gutter
  }) => {
    let mergedStyle = __spreadValues({}, style);
    if (gutter) {
      mergedStyle = __spreadValues(__spreadValues(__spreadValues({}, gutter[0] > 0 ? {
        paddingLeft: gutter[0] / 2,
        paddingRight: gutter[0] / 2
      } : {}), gutter[1] > 0 ? {
        paddingTop: gutter[1] / 2,
        paddingBottom: gutter[1] / 2
      } : {}), mergedStyle);
    }
    if (flex) {
      mergedStyle.flex = parseFlex(flex);
    }
    return /* @__PURE__ */ React.createElement("div", _extends({}, others, {
      style: mergedStyle,
      className: classes
    }), children);
  });
};
var stdin_default = FlexItem;
export {
  stdin_default as default
};

==> rc-ui-lib-2.1.3.tgz: package/es/flex/FlexItem.js <==
var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t)
        ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import React, { useContext } from "react";
import classnames from "classnames";
import FlexContext from "./FlexContext";
import ConfigProviderContext from "../config-provider/ConfigProviderContext";
const FlexItem = (props) => {
  const {
    prefixCls,
    createNamespace
  } = useContext(ConfigProviderContext);
  const [bem] = createNamespace("flexitem", prefixCls);
  const _a = props, {
    style,
    className,
    span,
    children,
    flex
  } = _a, others = __objRest(_a, [
    "style",
    "className",
    "span",
    "children",
    "flex"
  ]);
  const classes = classnames(bem([span == null ? void 0 : span.toString()]), className);
  const parseFlex = (_flex) => {
    if (typeof _flex === "number") {
      return `${_flex} ${_flex} auto`;
    }
    if (/^\d+(\.\d+)?(px|em|rem|%)$/.test(_flex)) {
      return `0 0 ${_flex}`;
    }
    return _flex;
  };
  return /* @__PURE__ */ React.createElement(FlexContext.Consumer, null, ({
    gutter
  }) => {
    let mergedStyle = __spreadValues({}, style);
    if (gutter) {
      mergedStyle = __spreadValues(__spreadValues(__spreadValues({}, gutter[0] > 0 ? {
        paddingLeft: gutter[0] / 2,
        paddingRight: gutter[0] / 2
      } : {}), gutter[1] > 0 ? {
        paddingTop: gutter[1] / 2,
        paddingBottom: gutter[1] / 2
      } : {}), mergedStyle);
    }
    if (flex) {
      mergedStyle.flex = parseFlex(flex);
    }
    return /* @__PURE__ */ React.createElement("div", _extends({}, others, {
      style: mergedStyle,
      className: classes
    }), children);
  });
};
var stdin_default = FlexItem;
export {
  stdin_default as default
};
